@@ -192,6 +192,13 @@ sub fetch_para {
     my $ret = $orig_fetch_para->($self, @_);
     my $lines = $self->{line};
     my $linno = $self->{line_no};
+
+    # concat 2 lines codes (functions with default behaviour) to make it preprocessed like C-like synopsis
+    if (@$lines == 2) {
+        $lines->[0] .= ' '.$lines->[1];
+        splice(@$lines, 1, 1);
+        splice(@$linno, 1, 1);
+    }
     
     if ($lines->[0] and $lines->[0] =~ /^([A-Z]+)\s*\{/) {
         $lines->[0] = "$1:";
